#ifdef EXPORT_DECLSPEC
#define DECLSPEC extern "C" __declspec(dllexport) int __stdcall
#else
#define DECLSPEC extern "C" __declspec(dllimport) int __stdcall
#endif

////////////////////////////////////////////////////////////
// Return code
////////////////////////////////////////////////////////////

#define LE_FAIL		0
#define LE_SUCCESS	1

////////////////////////////////////////////////////////////
// Key code
////////////////////////////////////////////////////////////

#define LE_REMOTE_KEY_0          0x0000
#define LE_REMOTE_KEY_1          0x0001
#define LE_REMOTE_KEY_2          0x0002
#define LE_REMOTE_KEY_3          0x0003
#define LE_REMOTE_KEY_4          0x0004
#define LE_REMOTE_KEY_5          0x0005
#define LE_REMOTE_KEY_6          0x0006
#define LE_REMOTE_KEY_7          0x0007
#define LE_REMOTE_KEY_8          0x0008
#define LE_REMOTE_KEY_9          0x0009
#define LE_REMOTE_KEY_A          0x000a
#define LE_REMOTE_KEY_B          0x000b
#define LE_REMOTE_KEY_C          0x000c
#define LE_REMOTE_KEY_D          0x000d
#define LE_REMOTE_KEY_E          0x000e
#define LE_REMOTE_KEY_F          0x000f
#define LE_REMOTE_KEY_LEFT       0x0010
#define LE_REMOTE_KEY_RIGHT      0x0011
#define LE_REMOTE_KEY_UP         0x0012
#define LE_REMOTE_KEY_DOWN       0x0013
#define LE_REMOTE_KEY_ENTER      0x0014
#define LE_REMOTE_KEY_PAGEUP     0x0015
#define LE_REMOTE_KEY_PAGEDOWN   0x0016
#define LE_REMOTE_KEY_MENU       0x0017
#define LE_REMOTE_KEY_DISPLAY    0x0018
#define LE_REMOTE_KEY_TIMECOUNT  0x0019
#define LE_REMOTE_KEY_HEXCODE    0x001a
#define LE_REMOTE_KEY_DATACODE   0x001b
#define LE_REMOTE_KEY_ZOOM       0x001b
#define LE_REMOTE_KEY_DELETE     0x001c
#define LE_REMOTE_KEY_TOP        0x001c
#define LE_REMOTE_KEY_DONTCARE   0x001d
#define LE_REMOTE_KEY_BOTTOM     0x001d
#define LE_REMOTE_KEY_LOADSAVE   0x001e
#define LE_REMOTE_KEY_FIND       0x001f
#define LE_REMOTE_KEY_PRINT      0x0020
#define LE_REMOTE_KEY_RUN        0x0021
#define LE_REMOTE_KEY_STOP       0x0022
#define LE_REMOTE_KEY_SHIFTON    0x0023
#define LE_REMOTE_KEY_ESC        0x0024
#define LE_REMOTE_KEY_POWER      0x0030
#define LE_REMOTE_KEY_F1         0x0031
#define LE_REMOTE_KEY_F2         0x0032
#define LE_REMOTE_KEY_F3         0x0033
#define LE_REMOTE_KEY_F4         0x0034
#define LE_REMOTE_KEY_F5         0x0035

#define LE_REMOTE_KEY_SHIFT      0x0080

////////////////////////////////////////////////////////////
// Setup
////////////////////////////////////////////////////////////

struct LE_LMWORD
{
	unsigned short wMask;
	unsigned short wPattern;
};
struct LE_LMBYTE
{
	unsigned char bMask;
	unsigned char bPattern;
};

typedef char LE_LPROTOCOL;
enum
{
    LE_LPROTOCOL_UNKNOWN = -1,
    LE_LPROTOCOL_ASYNC   = 0,
    LE_LPROTOCOL_SYNC    = 1,
    LE_LPROTOCOL_HDLC    = 2,
    LE_LPROTOCOL_PPP     = 3,
    LE_LPROTOCOL_IRDA    = 4,
    LE_LPROTOCOL_I2C     = 5,
    LE_LPROTOCOL_BURST   = 6,
    LE_LPROTOCOL_SPI     = 10,
    LE_LPROTOCOL_MODBUS  = 15,
    LE_LPROTOCOL_PROFIBUS= 17,
};
typedef char LE_BUFSIMDATA;
enum
{
    LE_BUFSIMDATA_BUF1S = 0,
    LE_BUFSIMDATA_BUF1R = 1,
    LE_BUFSIMDATA_BUF2S = 2,
    LE_BUFSIMDATA_BUF2R = 3
};
typedef char LE_PROGRAM;
enum
{
    LE_PROGRAM_A = 0,
    LE_PROGRAM_B = 1,
    LE_PROGRAM_C = 2,
    LE_PROGRAM_D = 3,
    NOF_LE_PROGRAM = 4
};
typedef char LE_STDTABLENO;
enum
{
    LE_STDTABLENO_0    = 0,
    LE_STDTABLENO_1    = 1,
    LE_STDTABLENO_2    = 2,
    LE_STDTABLENO_3    = 3,
    LE_STDTABLENO_4    = 4,
    LE_STDTABLENO_5    = 5,
    LE_STDTABLENO_6    = 6,
    LE_STDTABLENO_7    = 7,
    LE_STDTABLENO_8    = 8,
    LE_STDTABLENO_9    = 9,
    LE_STDTABLENO_A    = 10,
    LE_STDTABLENO_B    = 11,
    LE_STDTABLENO_C    = 12,
    LE_STDTABLENO_D    = 13,
    LE_STDTABLENO_E    = 14,
    LE_STDTABLENO_F    = 15,
    LE_STDTABLENO_ENQ  = 16,
    LE_STDTABLENO_ACK  = 17,
    LE_STDTABLENO_NAK  = 18,
    LE_STDTABLENO_WACK = 19,
    LE_STDTABLENO_EOT  = 20,
    LE_STDTABLENO_ACK0 = 21,
    LE_STDTABLENO_ACK1 = 22,
    LE_STDTABLENO_RVI  = 23,
    LE_STDTABLENO_TTD  = 24,
    LE_STDTABLENO_FOX  = 25,
    LE_STDTABLENO_MSG1 = 26,
    LE_STDTABLENO_MSG2 = 27,
    LE_STDTABLENO_DC1  = 28,
    LE_STDTABLENO_DC3  = 29,
    LE_STDTABLENO_NULL = -1,
    NOF_LE_STDTABLENO_USER = 16,
    NOF_LE_STDTABLENO_ALL  = 30
};
typedef char LE_FLOWWATCH;
enum
{
    LE_FLOWWATCH_CS  = 0,
    LE_FLOWWATCH_CD  = 1
};
typedef char LE_FLOWOPERATE;
enum
{
    LE_FLOWOPERATE_RS  = 0,
    LE_FLOWOPERATE_ER  = 1
};
typedef char LE_LOOPBACKLINE;
enum
{
    LE_LOOPBACKLINE_ERDR = 0,
    LE_LOOPBACKLINE_ERCD = 1
};
typedef char LE_BERTPATTERN;
enum
{
    LE_BERTPATTERN_63     = 0,
    LE_BERTPATTERN_511    = 1,
    LE_BERTPATTERN_2047   = 2,
    LE_BERTPATTERN_MARK   = 3,
    LE_BERTPATTERN_SPACE  = 4,
    LE_BERTPATTERN_ALT    = 5,
    LE_BERTPATTERN_DBLALT = 6,
    LE_BERTPATTERN_3IN24  = 7,
    LE_BERTPATTERN_1IN16  = 8,
    LE_BERTPATTERN_1IN8   = 9,
    LE_BERTPATTERN_1IN4   = 10,
    LE_BERTPATTERN_PN15   = 11,
    LE_BERTPATTERN_PN20   = 12,
    LE_BERTPATTERN_PN23   = 13
};
typedef char LE_BERTCOUNT;
enum
{
    LE_BERTCOUNT_1E3 = 0,
    LE_BERTCOUNT_1E4 = 1,
    LE_BERTCOUNT_1E5 = 2,
    LE_BERTCOUNT_1E6 = 3,
    LE_BERTCOUNT_1E7 = 4,
    LE_BERTCOUNT_1E8 = 5,
    LE_BERTCOUNT_1E9 = 6
};
typedef char LE_BERTMODEEX;
enum
{
    LE_BERTMODEEX_CONTINUE = 0,
    LE_BERTMODEEX_RBIT     = 1,
    LE_BERTMODEEX_RUNTIME  = 2,
    LE_BERTMODEEX_REPEAT   = 3,
    NOF_LE_BERTMODEEX    = 4
};

typedef char LE_DATACODE;
enum
{
    LE_DATACODE_ASCII     = 0,
    LE_DATACODE_EBCDIC    = 1,
    LE_DATACODE_EBCDIK    = 2,
    LE_DATACODE_JIS7      = 3,
    LE_DATACODE_JIS8      = 4,
    LE_DATACODE_HEX       = 5,
    LE_DATACODE_EBCD      = 6,
    LE_DATACODE_TRANSCODE = 7,
    LE_DATACODE_IPARS     = 8,
    LE_DATACODE_BAUDOT    = 9,
    NOF_LE_DATACODE       = 10
};
typedef char LE_DATABIT;
enum
{
    LE_DATABIT_5   = 0,
    LE_DATABIT_6   = 1,
    LE_DATABIT_7   = 2,
    LE_DATABIT_8   = 3
};
typedef char LE_PARITY;
enum
{
    LE_PARITY_NONE  = 0,
    LE_PARITY_ODD   = 1,
    LE_PARITY_EVEN  = 2,
    LE_PARITY_MARK  = 3,
    LE_PARITY_SPACE = 4,
    LE_PARITY_MP    = 5
};
typedef char LE_STOPBIT;
enum
{
    LE_STOPBIT_1   = 0,
    LE_STOPBIT_2   = 1
};
typedef char LE_BCC;
enum
{
    LE_BCC_NONE     = 0,
    LE_BCC_LRC_ODD  = 1,
    LE_BCC_LRC_EVEN = 2,
    LE_BCC_CRC_16   = 3,
    LE_BCC_CRC_ITUT = 4,
    LE_BCC_CRC_6    = 5,
    LE_BCC_CRC_12   = 6
};
typedef char LE_DATASEQUENCE;
enum
{
    LE_DATASEQUENCE_LSBFIRST = 0,
    LE_DATASEQUENCE_MSBFIRST = 1
};
typedef char LE_DATAFORMAT;
enum
{
    LE_DATAFORMAT_NRZ         = 0,
    LE_DATAFORMAT_NRZI        = 1,
    LE_DATAFORMAT_FM0         = 2,
    LE_DATAFORMAT_FM1         = 3,
    LE_DATAFORMAT_MANCHESTER0 = 4,
    LE_DATAFORMAT_MANCHESTER1 = 5
};
typedef char LE_CLOCK;
enum
{
    LE_CLOCK_ST1 = 0,
    LE_CLOCK_ST2 = 1,
    LE_CLOCK_RT  = 2,
    LE_CLOCK_AR  = 3
};
typedef char LE_FCS;
enum
{
    LE_FCS_NONE = 0,
    LE_FCS_16   = 1,
    LE_FCS_32   = 2
};
typedef char LE_HDLCIDLEMODE;
enum
{
    LE_HDLCIDLEMODE_MARK = 0,
    LE_HDLCIDLEMODE_FLAG = 1
};
typedef char LE_HDLCFRAME;
enum
{
    LE_HDLCFRAME_NONE  = -1,
    LE_HDLCFRAME_SDLC  = 0,
    LE_HDLCFRAME_SDLCX = 1,
    LE_HDLCFRAME_X25   = 2,
    LE_HDLCFRAME_X25X  = 3,
    LE_HDLCFRAME_LAPD  = 4
};
typedef char LE_HDLCPACKET;
enum
{
    LE_HDLCPACKET_NONE = -1,
    LE_HDLCPACKET_X25  = 0,
    LE_HDLCPACKET_LAPD = 1
};
typedef char LE_I2CSIMMODE;
enum
{
    LE_I2CSIMMODE_SLAVE  = 0,
    LE_I2CSIMMODE_MASTER = 1
};
typedef char LE_SPISIMMODE;
enum
{
    LE_SPISIMMODE_SLAVE  = 0,
    LE_SPISIMMODE_MASTER = 1
};
typedef char LE_SPICPOL;
enum
{
    LE_SPICPOL_0   = 0,
    LE_SPICPOL_1   = 1
};
typedef char LE_SPICPHA;
enum
{
    LE_SPICPHA_0   = 0,
    LE_SPICPHA_1   = 1
};
typedef char LE_MODBUSTRANSM;
enum
{
    LE_MODBUSTRANSM_RTU   = 0,
    LE_MODBUSTRANSM_ASCII = 1
};
typedef char LE_IFPORT;
enum
{
    LE_IFPORT_MAIN = 0,
    LE_IFPORT_SUB  = 1
};
typedef char LE_IFMODE;
enum
{
    LE_IFMODE_DTE = 0,
    LE_IFMODE_DCE = 1
};
typedef char LE_IFPOLARITY;
enum
{
    LE_IFPOLARITY_NORMAL = 0,
    LE_IFPOLARITY_INVERT = 1
};
typedef char LE_IFDRVCTRL;
enum
{
    LE_IFDRVCTRL_OFF    = 0,
    LE_IFDRVCTRL_MANUAL = 1,
    LE_IFDRVCTRL_AUTO   = 2
};
typedef char LE_CAPTUREBUF;
enum
{
    LE_CAPTUREBUF_0   = 0,
    LE_CAPTUREBUF_1   = 1,
    LE_CAPTUREBUF_2   = 2,
};
typedef char LE_IDLETIMEREC;
enum
{
    LE_IDLETIMEREC_OFF   = 0,
    LE_IDLETIMEREC_100ms = 1,
    LE_IDLETIMEREC_10ms  = 2,
    LE_IDLETIMEREC_1ms   = 3
};
typedef char LE_TIMESTAMPREC;
enum
{
    LE_TIMESTAMPREC_OFF    = 0,
    LE_TIMESTAMPREC_DHM    = 1,
    LE_TIMESTAMPREC_HMS    = 2,
    LE_TIMESTAMPREC_MS10ms = 3,
    LE_TIMESTAMPREC_100us  = 4,
    LE_TIMESTAMPREC_10us   = 5,
    LE_TIMESTAMPREC_1us    = 6,
    LE_EXTIMESTAMPREC_YMDHM    = 0x21,
    LE_EXTIMESTAMPREC_MDHMS    = 0x22,
    LE_EXTIMESTAMPREC_DHMS10ms = 0x23
};
typedef char LE_IFLEVELEX;
enum
{
    LE_IFLEVELEX_5V0 = 0,
    LE_IFLEVELEX_3V3 = 1,
    LE_IFLEVELEX_2V5 = 2,
    LE_IFLEVELEX_1V8 = 3
};
typedef char LE_IFOUTTYPE;
enum
{
    LE_IFOUTTYPE_PU   = 0,
    LE_IFOUTTYPE_NOPU = 1,
    LE_IFOUTTYPE_CMOS = 2
};

#define LE_LTABLE_FLAG_BCC_FCS 0x01
#define LE_LTABLE_FLAG_PARITY_MP 0x02
struct LE_LTABLE{
	int length;
	unsigned char character[16384];
	unsigned char flag[16384];
};
struct LE_LPROGRAM{
	int length;
	unsigned char program_step[512][16];
};

typedef char LE_TRGFACTOR;
enum
{
    LE_TRGFACTOR_ERROR     = 0,
    LE_TRGFACTOR_CHARACTER = 1,
    LE_TRGFACTOR_LINE      = 2,
    LE_TRGFACTOR_TMCT      = 3,
    LE_TRGFACTOR_IDLE      = 4,
    LE_TRGFACTOR_EXTERNAL  = 5,
    NOF_LE_TRGFACTOR       = 6
};
typedef unsigned char LE_TRGERROR;
enum
{
    LE_TRGERRORBIT_PARITY  = 0,
    LE_TRGERRORBIT_FRAMING = 1,
    LE_TRGERRORBIT_BCC     = 2,
    LE_TRGERRORBIT_BRK_ABT = 3,
    LE_TRGERRORBIT_SHORTF  = 4
};
enum
{
    LE_TRGERROR_NULL    = 0x00,
    LE_TRGERROR_PARITY  = 1 << LE_TRGERRORBIT_PARITY,
    LE_TRGERROR_FRAMING = 1 << LE_TRGERRORBIT_FRAMING,
    LE_TRGERROR_BCC     = 1 << LE_TRGERRORBIT_BCC,
    LE_TRGERROR_BRK_ABT = 1 << LE_TRGERRORBIT_BRK_ABT,
    LE_TRGERROR_SHORTF  = 1 << LE_TRGERRORBIT_SHORTF,
    LE_TRGERROR_ALL     = LE_TRGERROR_PARITY | LE_TRGERROR_FRAMING | LE_TRGERROR_BCC | LE_TRGERROR_BRK_ABT | LE_TRGERROR_SHORTF
};
typedef char LE_TRGEDGE;
enum
{
    LE_TRGEDGE_RISING  = 0,
    LE_TRGEDGE_FALLING = 1
};
typedef char LE_TIMERCOUNTER;
enum
{
    LE_TIMERCOUNTER_TIMER0   = 0,
    LE_TIMERCOUNTER_TIMER1   = 1,
    LE_TIMERCOUNTER_COUNTER0 = 2,
    LE_TIMERCOUNTER_COUNTER1 = 3,
    LE_TIMERCOUNTER_TIMER2   = 4,
    LE_TIMERCOUNTER_TIMER3   = 5,
    LE_TIMERCOUNTER_COUNTER2 = 6,
    LE_TIMERCOUNTER_COUNTER3 = 7
};
struct LE_TRIGGERFACTOR
{
	LE_TRGFACTOR eFactor;
	LE_TRGERROR mfError;
	char fSequence;
	LE_LMBYTE mbSd[8];
	LE_LMBYTE mbRd[8];
	LE_LMBYTE mbW[3];
	LE_LMBYTE mbLine;
	LE_TIMERCOUNTER eTimerCounter;
	LE_TRGEDGE eEdge;
	unsigned short usIdleTime;
};
typedef char LE_TRGACTION;
enum
{
    LE_TRGACTION_BUZZER  = 0,
    LE_TRGACTION_STOP    = 1,
    LE_TRGACTION_SAVE    = 2,
    LE_TRGACTION_TIMER   = 3,
    LE_TRGACTION_COUNTER = 4,
    LE_TRGACTION_TRIGSW  = 5,
    LE_TRGACTION_SEND    = 6,
    LE_TRGACTION_TRGOUT  = 7,
    LE_TRGACTION_LEDOUT  = 8
};
typedef char LE_TRGSTOP;
enum
{
    LE_TRGSTOP_QUICK  = 0,
    LE_TRGSTOP_BEFORE = 1,
    LE_TRGSTOP_CENTER = 2,
    LE_TRGSTOP_AFTER  = 3
};
typedef char LE_TRGTIMERACTION;
enum
{
    LE_TRGTIMERACTION_START   = 0,
    LE_TRGTIMERACTION_STOP    = 1,
    LE_TRGTIMERACTION_RESTART = 2
};
typedef char LE_TRGCOUNTERACTION;
enum
{
    LE_TRGCOUNTERACTION_INCREMENT = 0,
    LE_TRGCOUNTERACTION_CLEAR     = 1
};
typedef char LE_TRGSW;
enum
{
    LE_TRGSW_DISABLE = 0,
    LE_TRGSW_ENABLE  = 1,
    LE_TRGSW_CHANGE  = 2
};
typedef char LE_TRGLED;
enum
{
    LE_TRGLED_1 = 0,
    LE_TRGLED_2 = 1
};
typedef char LE_TRGLEDACT;
enum
{
    LE_TRGLEDACT_OFF = 0,
    LE_TRGLEDACT_ON = 1,
    LE_TRGLEDACT_CHANGE = 2
};
typedef char LE_TIMER;
enum
{
    LE_TIMER_0   = 0,
    LE_TIMER_1   = 1,
    LE_TIMER_2   = 2,
    LE_TIMER_3   = 3,
    NOF_LE_TIMER = 4
};
typedef char LE_COUNTER;
enum
{
    LE_COUNTER_0   = 0,
    LE_COUNTER_1   = 1,
    LE_COUNTER_2   = 2,
    LE_COUNTER_3   = 3,
    NOF_LE_COUNTER = 4
};
typedef char LE_TRIGGER;
enum
{
    LE_TRIGGER_0   = 0,
    LE_TRIGGER_1   = 1,
    LE_TRIGGER_2   = 2,
    LE_TRIGGER_3   = 3,
    LE_TRIGGER_4   = 4,
    LE_TRIGGER_5   = 5,
    LE_TRIGGER_6   = 6,
    LE_TRIGGER_7   = 7,
    NOF_LE_TRIGGER = 8
};
struct LE_TRIGGERACTION
{
	LE_TRGACTION eAction;
	unsigned char bNumber;
	LE_TRGSTOP eStopOffset;
	unsigned short usSaveOffsetM;
	unsigned short usSaveOffsetP;
	LE_TIMER eTimer;
	LE_TRGTIMERACTION eTimerAction;
	LE_COUNTER eCounter;
	LE_TRGCOUNTERACTION eCounterAction;
	LE_TRIGGER eTriggerNo;
	LE_TRGSW eTriggerSw;
	LE_STDTABLENO eTable;
	unsigned long ulResponseTime;
	LE_TRGLED eLed;
	LE_TRGLEDACT eLedAct;
};

#define STATE_RUN            0x00000100
#define STATE_BERT           0x00000800
#define STATE_BERTSYNC       0x00001000

struct LE_DATABERT{
    long Savail;
    __int64 R_Bit;
    __int64 E_Bit;
    double Bit_ER;
    short Loss;
    __int64 R_Blk;
    __int64 E_Blk;
    double Blk_ER;
    short E_Sec;
    double EFS;
};

////////////////////////////////////////////////////////////
// Protocol
////////////////////////////////////////////////////////////
struct LE_SETUP_PROTOCOL
{
	LE_LPROTOCOL eProtocol;
	union {
		struct {
			long lSpeedSd;
			long lSpeedRd;
			LE_DATACODE eDataCode;
			LE_DATABIT eDataBit;
			LE_PARITY eParity;
			LE_STOPBIT eStopBit;
			LE_DATAFORMAT eDataFormat;
			unsigned char bFrmEndCharCount;
			char cFrmEndChar[1];
			char cFrmEndTime;
			LE_BCC eBcc;
			unsigned char bBeginCharCount;
			char cBeginChar[2];
			unsigned char bEndCharCount;
			char cEndChar[2];
			unsigned char bItbCharCount;
			char cItbChar[1];
			char fTransparent;
			char cDleChar[1];
			LE_DATASEQUENCE eSequence;
		} async;
		struct
		{
			long lSpeedSd;
			long lSpeedRd;
			LE_DATACODE eDataCode;
			LE_DATABIT eDataBit;
			LE_PARITY eParity;
			LE_CLOCK eClock;
			LE_DATAFORMAT eDataFormat;
			unsigned char bSynCharCount;
			char cSynChar[2];
			char cRstChar[1];
			unsigned char bRstRepeat;
			unsigned char bSuppressCharCount;
			char cSuppressChar[1];
			LE_BCC eBcc;
			unsigned char bBeginCharCount;
			char cBeginChar[2];
			unsigned char bEndCharCount;
			char cEndChar[2];
			unsigned char bItbCharCount;
			char cItbChar[1];
			char fTransparent;
			char cDleChar[1];
			LE_DATASEQUENCE eSequence;
		} sync;
		struct
		{
			long lSpeedSd;
			long lSpeedRd;
			LE_DATACODE eDataCode;
			LE_CLOCK eClock;
			LE_DATAFORMAT eDataFormat;
			LE_FCS eFcs;
			char fFilterSd;
			char cFilterSdAddr[1];
			char fFilterRd;
			char cFilterRdAddr[1];
			LE_HDLCIDLEMODE eIdleMode;
			char cLeadingCount;
			LE_HDLCFRAME eFrameProtocol;
			LE_HDLCPACKET ePacketProtocol;
			LE_LMBYTE mbFilterSdEx[2];
			LE_LMBYTE mbFilterRdEx[2];
		} hdlc;
		struct
		{
			long lSpeedSd;
			long lSpeedRd;
			LE_DATACODE eDataCode;
			char fSuppress;
			LE_FCS eFcs;
		} ppp;
		struct
		{
			long lSpeed;
			LE_DATACODE eDataCode;
			char fSuppress;
		} irda;
		struct
		{
			long lSpeed;
			LE_DATACODE eDataCode;
			LE_I2CSIMMODE eI2cSimMode;
			char f10BitAddr;
			short sSlaveAddr;
		} i2c;
		struct
		{
			LE_DATACODE eDataCode;
			LE_DATABIT eDataBit;
			LE_PARITY eParity;
			unsigned char bFrmEndCharCount;
			char cFrmEndChar[1];
			char cFrmEndTime;
			LE_DATASEQUENCE eSequence;
		} burst;
		struct
		{
			long lSpeed;
			LE_DATACODE eDataCode;
			LE_SPISIMMODE eSpiSimMode;
			LE_SPICPOL eSpiCPol;
			LE_SPICPHA eSpiCPha;
			long lFrmEndTime;
			char cFrmEndTime;
			LE_DATASEQUENCE eSequence;
		} spi;
		struct
		{
			long lSpeed;
			LE_MODBUSTRANSM eTransMode;
			LE_PARITY eParity;
		} modbus;
		struct
		{
			long lSpeed;
		} profibus;
	};
};
////////////////////////////////////////////////////////////
// Function
////////////////////////////////////////////////////////////

DECLSPEC LEGetDllVersion(short *version);
DECLSPEC LEConnect(char *com);
DECLSPEC LEDisconnect();
DECLSPEC LEGetDateTime(SYSTEMTIME *pTime);
DECLSPEC LESetDateTime(SYSTEMTIME Time);

DECLSPEC LEStartOnlineCallBack(void (*CallBackFunc)(void *, int), int iFormat);
DECLSPEC LEStartManualCallBack(void (*CallBackFunc)(void *, int), int iFormat, unsigned long ulDelayTime, unsigned long ulIdleTime, char fRepeat);
DECLSPEC LEStartBufferCallBack(void (*CallBackFunc)(void *, int), int iFormat, unsigned long ulDelayTime, unsigned long ulIdleTime, char fRepeat, LE_BUFSIMDATA eData);
DECLSPEC LEStartProgramCallBack(void (*CallBackFunc)(void *, int), int iFormat, LE_PROGRAM eProgram);
DECLSPEC LEStartProgramCallBack2(void (*CallBackFunc)(void *, int), int iFormat, LE_PROGRAM eProgram, void (*CallBackProgress)(unsigned long, unsigned long));
DECLSPEC LEStartFlowSendCharCallBack(void (*CallBackFunc)(void *, int), int iFormat, char fInitial, char cXon, char cXoff, LE_STDTABLENO eTable, unsigned long ulIdleTime);
DECLSPEC LEStartFlowSendLineCallBack(void (*CallBackFunc)(void *, int), int iFormat, char fInitial, LE_FLOWWATCH eWatch, LE_FLOWOPERATE eOperate, LE_STDTABLENO eTable, unsigned long ulIdleTime);
DECLSPEC LEStartFlowRecvCharCallBack(void (*CallBackFunc)(void *, int), int iFormat, char fInitial, char cXon, char cXoff, unsigned long ulOnCount, unsigned long ulOffTime);
DECLSPEC LEStartFlowRecvLineCallBack(void (*CallBackFunc)(void *, int), int iFormat, char fInitial, LE_FLOWWATCH eWatch, LE_FLOWOPERATE eOperate, unsigned long ulOnCount, unsigned long ulOffTime);
DECLSPEC LEStartEchoBufferCallBack(void (*CallBackFunc)(void *, int), int iFormat, unsigned long ulResponseTime);
DECLSPEC LEStartEchoCharCallBack(void (*CallBackFunc)(void *, int), int iFormat);
DECLSPEC LEStartEchoLoopbackCallBack(void (*CallBackFunc)(void *, int), int iFormat, LE_LOOPBACKLINE eLoopbackLine);
DECLSPEC LEStartBertContinue(LE_BERTPATTERN ePattern, int flow);
DECLSPEC LEStartBertRbit(LE_BERTPATTERN ePattern, LE_BERTCOUNT eCount, int flow);
DECLSPEC LEStartBertRuntime(LE_BERTPATTERN ePattern, ULONG ulTestTime, int flow);
DECLSPEC LEStartBertRepeat(LE_BERTPATTERN ePattern, short sTimeResolution, int flow);

DECLSPEC LEReStartCallBack(void (*CallBackFunc)(void *, int), int iFormat );
DECLSPEC LEStartOnline();
DECLSPEC LEStop();
DECLSPEC LEGetRunStatus(int *fRun);
DECLSPEC LEEmulationKey(int iCode);

DECLSPEC LEGetTable(int number, LE_LTABLE *table);
DECLSPEC LESetTable(int number, LE_LTABLE table);
DECLSPEC LESetTableString(int number, char *str );
DECLSPEC LEGetProgram(int number, LE_LPROGRAM *program);
DECLSPEC LESetProgram(int number, LE_LPROGRAM program);

DECLSPEC LESetTrigger(int number, LE_TRIGGERFACTOR factor, LE_TRIGGERACTION action);
DECLSPEC LESetTriggerOff(int number);
DECLSPEC LEGetTrigger(int number, char *fSw, LE_TRIGGERFACTOR *factor, LE_TRIGGERACTION *action);
DECLSPEC LEGetProtocol( LE_LPROTOCOL *eProtocol );
DECLSPEC LESetProtocol( LE_LPROTOCOL eProtocol );
DECLSPEC LEGetProtocolSetup( LE_SETUP_PROTOCOL *protocol );
DECLSPEC LESetProtocolSetup( LE_SETUP_PROTOCOL protocol );

DECLSPEC LEInterfaceRS232C( LE_IFMODE eMode, LE_IFPOLARITY ePolarity );
DECLSPEC LEInterfaceRS530( LE_IFMODE eMode, LE_IFPOLARITY ePolarity, char fV35Select, LE_IFDRVCTRL eDrvCtrl );
DECLSPEC LEInterfaceTTL( LE_IFLEVELEX eLevelEx, LE_IFPOLARITY ePolarity, LE_IFPOLARITY eClockPolarity, LE_IFOUTTYPE eOutType );
DECLSPEC LEInterfaceLineControlOff();
DECLSPEC LEInterfaceLineControlDTE( unsigned short usDelayRsOn, unsigned short usDelaySd,unsigned short usDelayRsOff, char fErSw);
DECLSPEC LEInterfaceLineControlDCE( unsigned short usDelayCsOn, unsigned short usDelayCsOff,unsigned short usDelayCdOn, unsigned short usDelayRd, unsigned short usDelayCdOff);
DECLSPEC LEGetInterfaceMode( LE_IFPORT *ePort, LE_IFMODE *eMode, LE_IFPOLARITY *ePolarity, char *fV35Select, LE_IFDRVCTRL *eDrvCtrl );

DECLSPEC LESetIdleTimeRec( LE_IDLETIMEREC eIdleTimeRec );
DECLSPEC LEGetIdleTimeRec( LE_IDLETIMEREC *eIdleTimeRec );
DECLSPEC LESetTimeStampRec( LE_TIMESTAMPREC eTimeStampRec );
DECLSPEC LEGetTimeStampRec( LE_TIMESTAMPREC *eTimeStampRec );
DECLSPEC LESetLineRec( char fLineStateRec );
DECLSPEC LEGetLineRec( char *fLineStateRec );
DECLSPEC LESetCaptureBuf( LE_CAPTUREBUF eCaptureBuf );
DECLSPEC LEGetCaptureBuf( LE_CAPTUREBUF *eCaptureBuf );

DECLSPEC LELoadDT(char *sFilename, void *dst, int *iSize, int iFormat);

DECLSPEC LEIsAbort();
DECLSPEC LESetBscTranslate( char fBscTranslate );
DECLSPEC LEGetBscTranslate( char *fBscTranslate );
DECLSPEC LEGetScreen(char *sFilename);

DECLSPEC LEGetState( unsigned long *state );
DECLSPEC LEGetBertDataCount( int *count );
DECLSPEC LEGetBertData( LE_DATABERT *bertdata, int *bertdatacount );

DECLSPEC LEImportPcap( char *sFilename );

////////////////////////////////////////////////////////////
// Monitor data
////////////////////////////////////////////////////////////

#define LE_MONDATA_FORMAT_1	1
#define LE_MONDATA_FORMAT_2	2

#define LE_MONSTATUS_DATA_VISIBLE	0x80
struct LE_MONDATAFORMAT1{
	unsigned char statusSD;
	unsigned char statusRD;
	unsigned char SD;
	unsigned char RD;
};

#define LE_MONSTATUS_SD_DATA_VISIBLE		0x80
#define LE_MONSTATUS_RD_DATA_VISIBLE		0x40
#define LE_MONSTATUS_SD_TIMESTAMP			0x01
#define LE_MONSTATUS_RD_TIMESTAMP			0x02
#define LE_MONSTATUS_IDLETIME				0x03
#define LE_MONSTATUS_CHANGE_CONTROLLINE		0x04

#define LE_MONSTATUS_DATASTATUS_SD_PARITY	0x01
#define LE_MONSTATUS_DATASTATUS_RD_PARITY	0x02

#define LE_CONTROLLINE_RS					0x01
#define LE_CONTROLLINE_CS					0x02
#define LE_CONTROLLINE_DR					0x04
#define LE_CONTROLLINE_CD					0x08
#define LE_CONTROLLINE_ER					0x10
#define LE_CONTROLLINE_SQ					0x20
#define LE_CONTROLLINE_CI					0x40
#define LE_CONTROLLINE_EX					0x80

struct LE_MONDATAFORMAT2{
	unsigned char framestatus;
	union {
		struct
		{
			unsigned char datastatus;
			unsigned char SD;
			unsigned char RD;
		} data;
		struct
		{
			unsigned char h;
			unsigned char m;
			unsigned char l;
		} time;
		struct
		{
			unsigned char oldstate;
			unsigned char newstate;
		} change_controlline;
	};
};

#define LE_PROGRESS_SDCOUNTER	0x00000001
#define LE_PROGRESS_RDCOUNTER	0x00000002
#define LE_PROGRESS_TIMER0		0x00000010
#define LE_PROGRESS_TIMER1		0x00000011
#define LE_PROGRESS_TIMER2		0x00000012
#define LE_PROGRESS_TIMER3		0x00000013
#define LE_PROGRESS_TIMERSET0	0x00000018
#define LE_PROGRESS_TIMERSET1	0x00000019
#define LE_PROGRESS_TIMERSET2	0x0000001a
#define LE_PROGRESS_TIMERSET3	0x0000001b
#define LE_PROGRESS_COUNTER0	0x00000020
#define LE_PROGRESS_COUNTER1	0x00000021
#define LE_PROGRESS_COUNTER2	0x00000022
#define LE_PROGRESS_COUNTER3	0x00000023
#define LE_PROGRESS_COUNTERSET0	0x00000028
#define LE_PROGRESS_COUNTERSET1	0x00000029
#define LE_PROGRESS_COUNTERSET2	0x0000002a
#define LE_PROGRESS_COUNTERSET3	0x0000002b
#define LE_PROGRESS_REGISTER0	0x00000030
#define LE_PROGRESS_REGISTER1	0x00000031
#define LE_PROGRESS_REGISTER2	0x00000032
#define LE_PROGRESS_REGISTER3	0x00000033
#define LE_PROGRESS_REGISTER4	0x00000034
#define LE_PROGRESS_REGISTER5	0x00000035
#define LE_PROGRESS_REGISTER6	0x00000036
#define LE_PROGRESS_REGISTER7	0x00000037
#define LE_PROGRESS_REGISTER8	0x00000038
#define LE_PROGRESS_REGISTER9	0x00000039
#define LE_PROGRESS_REGISTERA	0x0000003a
#define LE_PROGRESS_REGISTERB	0x0000003b
#define LE_PROGRESS_REGISTERC	0x0000003c
#define LE_PROGRESS_REGISTERD	0x0000003d
#define LE_PROGRESS_REGISTERE	0x0000003e
#define LE_PROGRESS_REGISTERF	0x0000003f

struct LE_PROGRESS{
	unsigned long progressitem;
	unsigned long value;
};
